pub fn unicode_math_properties(c: char) -> Option<MathCharProps>Expand description
Lookup Unicode math properties for a character, mirroring Perl’s %math_props in Unicode.pm
pub fn unicode_math_properties(c: char) -> Option<MathCharProps>Lookup Unicode math properties for a character, mirroring Perl’s %math_props in Unicode.pm